@@ -7,7 +7,7 @@ import yaml
 
 from .dataset_utils import count_classes_in_lab_dir, show_list_images, \
     show_class_images
-from os_com import os_com
+from . import os_com
 
 
 # print(f'{__file__}, {__name__}, {__package__}')
